# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2018-12-05 02:06:56 UTC
from __future__ import unicode_literals
import datetime

version = "2.0.8"
githash = "231c409a632dcbf2beae1c2dea5b843d81ede511"


major = 2
minor = 0
bugfix = 8

release = True
timestamp = datetime.datetime(2018, 12, 5, 2, 6, 56)
debug = False

astropy_helpers_version = ""

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
